@@ -69,14 +69,16 @@ class IRCApplication(object):
         Loads and starts the IRC bot for the entire application.
         """
         self.django = django
-        module_name, class_name = settings.BOT_CLASS.rsplit(".", 1)
-        __import__(module_name)
-        bot_class = getattr(sys.modules[module_name], class_name)
-        self.bot = bot_class(settings.IRC_HOST, settings.IRC_PORT,
-                             settings.IRC_CHANNEL, settings.BOT_NICKNAME,
-                             settings.BOT_PASSWORD)
-        spawn(self.bot.start)
-        spawn(self.bot_watcher)
+        self.bot = None
+        if settings.BOT_CLASS:
+            module_name, class_name = settings.BOT_CLASS.rsplit(".", 1)
+            __import__(module_name)
+            bot_class = getattr(sys.modules[module_name], class_name)
+            self.bot = bot_class(settings.IRC_HOST, settings.IRC_PORT,
+                                 settings.IRC_CHANNEL, settings.BOT_NICKNAME,
+                                 settings.BOT_PASSWORD)
+            spawn(self.bot.start)
+            spawn(self.bot_watcher)
         self.logger = getLogger("irc.webhooks")
         self.logger.setLevel(settings.LOG_LEVEL)
         self.logger.addHandler(StreamHandler())
@@ -105,6 +107,8 @@ class IRCApplication(object):
         url = environ["PATH_INFO"]
         params = dict([(k, request[k].value) for k in request])
         try:
+            if self.bot is None:
+                raise NotImplementedError
             response = self.bot.handle_webhook_event(environ, url, params)
         except NotImplementedError:
             return 404
@@ -245,7 +249,7 @@ def serve_forever(django=False):
     logger.addHandler(StreamHandler())
     app = IRCApplication(django)
     server = SocketIOServer((settings.HTTP_HOST, settings.HTTP_PORT), app)
-    print "%s [%s] listening on %s:%s" % (
+    print "%s [Bot: %s] listening on %s:%s" % (
         settings.GNOTTY_VERSION_STRING,
         app.bot.__class__.__name__,
         settings.HTTP_HOST,
